@@ -32,6 +32,8 @@ import q2_cutadapt
 import q2_cutadapt._demux
 import q2_cutadapt._trim
 
+import q2_cutadapt._examples as ex
+
 
 plugin = Plugin(
     name='cutadapt',
@@ -64,6 +66,11 @@ plugin.methods.register_function(
         'match_adapter_wildcards': Bool,
         'minimum_length': Int % Range(1, None),
         'discard_untrimmed': Bool,
+        'max_expected_errors': Float % Range(0, None),
+        'max_n': Float % Range(0, None),
+        'quality_cutoff_3end': Int % Range(0, None),
+        'quality_cutoff_5end': Int % Range(0, None),
+        'quality_base': Int % Range(0, None),
     },
     outputs=[
         ('trimmed_sequences', SampleData[SequencesWithQuality]),
@@ -109,6 +116,16 @@ plugin.methods.register_function(
                           'because that value produces empty sequence '
                           'records.',
         'discard_untrimmed': 'Discard reads in which no adapter was found.',
+        'max_expected_errors': 'Discard reads that exceed maximum expected '
+                               'erroneous nucleotides.',
+        'max_n': 'Discard reads with more than COUNT N bases. '
+                 'If COUNT_or_FRACTION is a number between 0 and 1, '
+                 'it is interpreted as a fraction of the read length.',
+        'quality_cutoff_3end': 'Trim nucleotides with Phred score quality '
+                               'lower than threshold from 3 prime end.',
+        'quality_cutoff_5end': 'Trim nucleotides with Phred score quality '
+                               'lower than threshold from 5 prime end.',
+        'quality_base': 'How the Phred score is encoded (33 or 64).',
     },
     output_descriptions={
         'trimmed_sequences': 'The resulting trimmed sequences.',
@@ -143,6 +160,11 @@ plugin.methods.register_function(
         'match_adapter_wildcards': Bool,
         'minimum_length': Int % Range(1, None),
         'discard_untrimmed': Bool,
+        'max_expected_errors': Float % Range(0, None),
+        'max_n': Float % Range(0, None),
+        'quality_cutoff_3end': Int % Range(0, None),
+        'quality_cutoff_5end': Int % Range(0, None),
+        'quality_base': Int % Range(0, None),
     },
     outputs=[
         ('trimmed_sequences', SampleData[PairedEndSequencesWithQuality]),
@@ -210,6 +232,16 @@ plugin.methods.register_function(
                           'because that value produces empty sequence '
                           'records.',
         'discard_untrimmed': 'Discard reads in which no adapter was found.',
+        'max_expected_errors': 'Discard reads that exceed maximum expected '
+                               'erroneous nucleotides.',
+        'max_n': 'Discard reads with more than COUNT N bases. '
+                 'If COUNT_or_FRACTION is a number between 0 and 1, '
+                 'it is interpreted as a fraction of the read length.',
+        'quality_cutoff_3end': 'Trim nucleotides with Phred score quality '
+                               'lower than threshold from 3 prime end.',
+        'quality_cutoff_5end': 'Trim nucleotides with Phred score quality '
+                               'lower than threshold from 5 prime end.',
+        'quality_base': 'How the Phred score is encoded (33 or 64).',
     },
     output_descriptions={
         'trimmed_sequences': 'The resulting trimmed sequences.',
@@ -270,6 +302,8 @@ plugin.methods.register_function(
                 'sample ids). Barcodes are expected to be located within the '
                 'sequence data (versus the header, or a separate barcode '
                 'file).',
+    examples={'demux_single': ex.cutadapt_demux_single
+              },
 )
 
 plugin.methods.register_function(
@@ -325,4 +359,6 @@ plugin.methods.register_function(
                 'sample ids). Barcodes are expected to be located within the '
                 'sequence data (versus the header, or a separate barcode '
                 'file).',
+    examples={'paired': ex.cutadapt_demux_paired,
+              },
 )
